@@ -1,12 +1,12 @@
-# Copyright (C) 2000, 2001 Hajimu UMEMOTO <ume@mahoroba.org>.
+# Copyright (C) 2000-2005 Hajimu UMEMOTO <ume@mahoroba.org>.
 # All rights reserved.
-# 
+#
 # This module is besed on perl5.005_55-v6-19990721 written by KAME
 # Project.
 #
 # Copyright (C) 1995, 1996, 1997, 1998, and 1999 WIDE Project.
 # All rights reserved.
-# 
+#
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
 # are met:
@@ -18,7 +18,7 @@
 # 3. Neither the name of the project nor the names of its contributors
 #    may be used to endorse or promote products derived from this software
 #    without specific prior written permission.
-# 
+#
 # THIS SOFTWARE IS PROVIDED BY THE PROJECT AND CONTRIBUTORS ``AS IS'' AND
 # ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 # IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -31,16 +31,16 @@
 # OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 # SUCH DAMAGE.
 
-# $Id: Socket6.pm,v 1.22 2001/09/17 16:06:37 ume Exp $
+# $Id: Socket6.pm,v 1.36 2005/08/27 16:54:55 ume Exp $
 
 package Socket6;
 
 use vars qw($VERSION @ISA @EXPORT %EXPORT_TAGS);
-$VERSION = "0.11";
+$VERSION = "0.19";
 
 =head1 NAME
 
-Socket6 - IPv6 related part of the C socket.h defines and structure manipulators 
+Socket6 - IPv6 related part of the C socket.h defines and structure manipulators
 
 =head1 SYNOPSIS
 
@@ -124,7 +124,7 @@ Functions supplied are:
     This function will croak if it determines it has not been
     passed an IPv6 structure.
 
-=item gethostbyname2 HOSTNAME, SERVNAME 
+=item gethostbyname2 HOSTNAME, FAMILY
 
 =item getaddrinfo NODENAME, SERVICENAME, [FAMILY, SOCKTYPE, PROTOCOL, FLAGS]
 
@@ -166,6 +166,7 @@ Functions supplied are:
     The arguments FAMILY and FLAGS are optional.
     Note: This function does not handle IPv6 scope identifiers,
     and should be used with care.
+    And, this function was deprecated in RFC3493.
     The getnameinfo function should be used instead.
 
 =item getipnodebyaddr FAMILY, ADDRESS
@@ -179,6 +180,7 @@ Functions supplied are:
 
     Note: This function does not handle IPv6 scope identifiers,
     and should be used with care.
+    And, this function was deprecated in RFC3493.
     The getaddrinfo function should be used instead.
 
 =item gai_strerror ERROR_NUMBER
@@ -186,11 +188,11 @@ Functions supplied are:
     This function returns a string corresponding to the error number
     passed in as an argument.
 
-=item inaddr6_any
+=item in6addr_any
 
     This function returns the 16-octet wildcard address.
 
-=item inadd6_loopback
+=item in6add_loopback
 
     This function returns the 16-octet loopback address.
 
@@ -216,6 +218,7 @@ require DynaLoader;
 	AI_ALL
 	AI_CANONNAME
 	AI_NUMERICHOST
+	AI_NUMERICSERV
 	AI_DEFAULT
 	AI_MASK
 	AI_PASSIVE
